## Summary

## Add the search source

### API

ℹ️ Restriction: API searches do not support complex queries (yet)

```
colrev search --add colrev.arxiv -p "https://arxiv.org/search/?query=fitbit&searchtype=all&abstracts=show&order=-announced_date_first&size=50"
```

## Links

- [arXiv](https://arxiv.org/)
